==> home-library-webapp-1.7.0-20170516.210508-23-sources.jar: org/apache/jackrabbit/j2ee/workspacemanager/versioning/RestoreVersion.java <==
package org.apache.jackrabbit.j2ee.workspacemanager.versioning;

import java.io.IOException;
import java.io.PrintWriter;

import javax.jcr.Repository;
import javax.jcr.Session;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.jackrabbit.j2ee.RepositoryAccessServlet;
import org.apache.jackrabbit.j2ee.workspacemanager.session.SessionManager;
import org.gcube.common.homelibary.model.servlet.ServletParameter;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.thoughtworks.xstream.XStream;
import com.thoughtworks.xstream.io.xml.DomDriver;

public class RestoreVersion extends HttpServlet {

	private static Logger logger = LoggerFactory.getLogger(RestoreVersion.class);
	private static final long serialVersionUID = 1L;

	public RestoreVersion() {
		super();
	}

	protected void doGet(HttpServletRequest request,
			HttpServletResponse response) throws ServletException, IOException {

		//		response.setContentType("text/plain");
		response.setContentType("text/html; charset=UTF-8");
		PrintWriter out = response.getWriter();

		String sessionId = request.getParameter(ServletParameter.UUID);

		String nodeID = request.getParameter(ServletParameter.ID);	
		String versionID = request.getParameter(ServletParameter.VERSION);	
		String remotePath = request.getParameter(ServletParameter.REMOTE_PATH);	
		//1.9 - Fri Jan 13 18:21:49 CET 2017

		logger.info("Servlet Restor version called with parameters: [ id: " + nodeID + " -  version: " + versionID + " -  remotePath: " + remotePath + "]");

		Repository rep = RepositoryAccessServlet.getRepository(getServletContext());
		Session session = null;
		XStream xstream = null;
		String xmlConfig = null;
		SessionManager sessionManager = null;
		boolean exist = false;
		try {
			xstream = new XStream(new DomDriver("UTF-8"));

			sessionManager = SessionManager.getInstance(rep);
			exist = sessionManager.sessionExists(sessionId); 
			if (exist){				
				session = sessionManager.getSession(sessionId);
			} else {
				session = sessionManager.newSession(request);
				sessionId = session.toString();
			}

			JCRVersioning versioning = new JCRVersioning(session, sessionManager.getLogin(request));
			versioning.restoreVersion(nodeID, remotePath, versionID);




		} catch (Exception e) {
			logger.error("Error repository ex " + e);
			xmlConfig = xstream.toXML(e.toString());
			response.setContentLength(xmlConfig.length());
			out.println(xmlConfig);

		} finally {
			if (!exist){
				sessionManager.releaseSession(sessionId);
				//				logger.info("Released session " + sessionId);
			}
			out.close();
			out.flush();
		}
	}

}

==> home-library-webapp-1.8.0-20170704.000904-44-sources.jar: org/apache/jackrabbit/j2ee/workspacemanager/versioning/RestoreVersion.java <==
package org.apache.jackrabbit.j2ee.workspacemanager.versioning;

import java.io.IOException;
import java.io.PrintWriter;

import javax.jcr.Repository;
import javax.jcr.Session;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.jackrabbit.j2ee.RepositoryAccessServlet;
import org.apache.jackrabbit.j2ee.workspacemanager.session.SessionManager;
import org.gcube.common.homelibary.model.servlet.ServletParameter;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.thoughtworks.xstream.XStream;
import com.thoughtworks.xstream.io.xml.DomDriver;

public class RestoreVersion extends HttpServlet {

	private static Logger logger = LoggerFactory.getLogger(RestoreVersion.class);
	private static final long serialVersionUID = 1L;

	public RestoreVersion() {
		super();
	}

	protected void doGet(HttpServletRequest request,
			HttpServletResponse response) throws ServletException, IOException {

		//		response.setContentType("text/plain");
		response.setContentType("text/html; charset=UTF-8");
		PrintWriter out = response.getWriter();

		String sessionId = request.getParameter(ServletParameter.UUID);

		String nodeID = request.getParameter(ServletParameter.ID);	
		String versionID = request.getParameter(ServletParameter.VERSION);	
		String remotePath = request.getParameter(ServletParameter.REMOTE_PATH);	
		//1.9 - Fri Jan 13 18:21:49 CET 2017

		logger.info("Servlet Restore Version called with parameters: [ id: " + nodeID + " -  version: " + versionID + " -  remotePath: " + remotePath + "]");

		Repository rep = RepositoryAccessServlet.getRepository(getServletContext());
		Session session = null;
		XStream xstream = null;
		String xmlConfig = null;
		SessionManager sessionManager = null;
		boolean exist = false;
		try {
			xstream = new XStream(new DomDriver("UTF-8"));

			sessionManager = SessionManager.getInstance(rep);
			exist = sessionManager.sessionExists(sessionId); 
			if (exist){				
				session = sessionManager.getSession(sessionId);
			} else {
				session = sessionManager.newSession(request);
				sessionId = session.toString();
			}

			JCRVersioning versioning = new JCRVersioning(session, sessionManager.getLogin(request));
			versioning.restoreVersion(nodeID, remotePath, versionID);


		} catch (Exception e) {
			logger.error("Error repository ex " + e);
			xmlConfig = xstream.toXML(e.toString());
			response.setContentLength(xmlConfig.length());
			out.println(xmlConfig);

		} finally {
			if (!exist){
				sessionManager.releaseSession(sessionId);
				//				logger.info("Released session " + sessionId);
			}
			out.close();
			out.flush();
		}
	}

}
